@@ -1,9 +1,8 @@
 package Proc::ChildError;
 
-our $DATE = '2014-11-18'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
-use 5.010001;
 use strict;
 use warnings;
 
@@ -60,7 +59,7 @@ Proc::ChildError - Explain process child error
 
 =head1 VERSION
 
-This document describes version 0.02 of Proc::ChildError (from Perl distribution Proc-ChildError), released on 2014-11-18.
+This document describes version 0.03 of Proc::ChildError (from Perl distribution Proc-ChildError), released on 2015-06-26.
 
 =head1 FUNCTIONS
 
@@ -90,6 +89,13 @@ Program name/path, to include in error messages:
 
 =back
 
+=head1 SEE ALSO
+
+L<IPC::System::Simple> provides a replacement for Perl's C<system()>, with the
+difference that it will print a diagnostic error message similar to what
+C<Proc::ChildError> provides. You only need to do C<use IPC::System::Simple
+qw(system)> and use C<system()> as usual. Recommended.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Proc-ChildError>.
@@ -112,7 +118,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
